# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .abstract_column import AbstractColumn
from .abstract_command_descriptor import AbstractCommandDescriptor
from .abstract_field import AbstractField
from .abstract_parser_test_result_log_entry import AbstractParserTestResultLogEntry
from .abstract_parser_test_result_log_line import AbstractParserTestResultLogLine
from .action import Action
from .add_entity_association_details import AddEntityAssociationDetails
from .add_fields_command_descriptor import AddFieldsCommandDescriptor
from .agent_upload import AgentUpload
from .archiving_configuration import ArchivingConfiguration
from .argument import Argument
from .association_summary_report import AssociationSummaryReport
from .attribute import Attribute
from .auto_lookups import AutoLookups
from .bottom_command_descriptor import BottomCommandDescriptor
from .bucket_command_descriptor import BucketCommandDescriptor
from .bucket_range import BucketRange
from .change_log_analytics_entity_compartment_details import ChangeLogAnalyticsEntityCompartmentDetails
from .change_log_analytics_log_group_compartment_details import ChangeLogAnalyticsLogGroupCompartmentDetails
from .change_log_analytics_object_collection_rule_compartment_details import ChangeLogAnalyticsObjectCollectionRuleCompartmentDetails
from .change_scheduled_task_compartment_details import ChangeScheduledTaskCompartmentDetails
from .char_encoding_collection import CharEncodingCollection
from .chart_column import ChartColumn
from .chart_data_column import ChartDataColumn
from .classify_column import ClassifyColumn
from .classify_command_descriptor import ClassifyCommandDescriptor
from .cluster_command_descriptor import ClusterCommandDescriptor
from .cluster_compare_command_descriptor import ClusterCompareCommandDescriptor
from .cluster_details_command_descriptor import ClusterDetailsCommandDescriptor
from .cluster_split_command_descriptor import ClusterSplitCommandDescriptor
from .column import Column
from .column_name import ColumnName
from .column_name_collection import ColumnNameCollection
from .command_descriptor import CommandDescriptor
from .create_acceleration_task_details import CreateAccelerationTaskDetails
from .create_log_analytics_entity_details import CreateLogAnalyticsEntityDetails
from .create_log_analytics_entity_type_details import CreateLogAnalyticsEntityTypeDetails
from .create_log_analytics_log_group_details import CreateLogAnalyticsLogGroupDetails
from .create_log_analytics_object_collection_rule_details import CreateLogAnalyticsObjectCollectionRuleDetails
from .create_namespace_details import CreateNamespaceDetails
from .create_scheduled_task_details import CreateScheduledTaskDetails
from .create_standard_task_details import CreateStandardTaskDetails
from .cron_schedule import CronSchedule
from .delete_command_descriptor import DeleteCommandDescriptor
from .delete_log_analytics_association import DeleteLogAnalyticsAssociation
from .delete_log_analytics_association_details import DeleteLogAnalyticsAssociationDetails
from .delta_command_descriptor import DeltaCommandDescriptor
from .demo_mode_command_descriptor import DemoModeCommandDescriptor
from .distinct_command_descriptor import DistinctCommandDescriptor
from .efd_regex_result import EfdRegexResult
from .entity_type_property import EntityTypeProperty
from .error_details import ErrorDetails
from .estimate_purge_data_size_details import EstimatePurgeDataSizeDetails
from .estimate_purge_data_size_result import EstimatePurgeDataSizeResult
from .eval_command_descriptor import EvalCommandDescriptor
from .event_stats_command_descriptor import EventStatsCommandDescriptor
from .export_content import ExportContent
from .export_details import ExportDetails
from .extended_fields_validation_result import ExtendedFieldsValidationResult
from .extract_command_descriptor import ExtractCommandDescriptor
from .extract_log_field_results import ExtractLogFieldResults
from .extract_log_header_details import ExtractLogHeaderDetails
from .extract_log_header_results import ExtractLogHeaderResults
from .field import Field
from .field_argument import FieldArgument
from .field_map import FieldMap
from .field_summary_command_descriptor import FieldSummaryCommandDescriptor
from .field_summary_report import FieldSummaryReport
from .field_value import FieldValue
from .fields_add_remove_field import FieldsAddRemoveField
from .fields_command_descriptor import FieldsCommandDescriptor
from .file_validation_response import FileValidationResponse
from .filter import Filter
from .filter_details import FilterDetails
from .filter_output import FilterOutput
from .fixed_frequency_schedule import FixedFrequencySchedule
from .function_field import FunctionField
from .generate_agent_object_name_details import GenerateAgentObjectNameDetails
from .head_command_descriptor import HeadCommandDescriptor
from .highlight_command_descriptor import HighlightCommandDescriptor
from .highlight_rows_command_descriptor import HighlightRowsCommandDescriptor
from .indexes import Indexes
from .label_names import LabelNames
from .label_priority import LabelPriority
from .label_priority_collection import LabelPriorityCollection
from .label_source_collection import LabelSourceCollection
from .label_source_summary import LabelSourceSummary
from .label_summary_report import LabelSummaryReport
from .link_command_descriptor import LinkCommandDescriptor
from .link_details_command_descriptor import LinkDetailsCommandDescriptor
from .literal_argument import LiteralArgument
from .log_analytics import LogAnalytics
from .log_analytics_associated_entity import LogAnalyticsAssociatedEntity
from .log_analytics_associated_entity_collection import LogAnalyticsAssociatedEntityCollection
from .log_analytics_association import LogAnalyticsAssociation
from .log_analytics_association_collection import LogAnalyticsAssociationCollection
from .log_analytics_association_parameter import LogAnalyticsAssociationParameter
from .log_analytics_association_parameter_collection import LogAnalyticsAssociationParameterCollection
from .log_analytics_collection_warning import LogAnalyticsCollectionWarning
from .log_analytics_config_work_request import LogAnalyticsConfigWorkRequest
from .log_analytics_config_work_request_collection import LogAnalyticsConfigWorkRequestCollection
from .log_analytics_config_work_request_payload import LogAnalyticsConfigWorkRequestPayload
from .log_analytics_config_work_request_summary import LogAnalyticsConfigWorkRequestSummary
from .log_analytics_entity import LogAnalyticsEntity
from .log_analytics_entity_collection import LogAnalyticsEntityCollection
from .log_analytics_entity_summary import LogAnalyticsEntitySummary
from .log_analytics_entity_summary_report import LogAnalyticsEntitySummaryReport
from .log_analytics_entity_type import LogAnalyticsEntityType
from .log_analytics_entity_type_collection import LogAnalyticsEntityTypeCollection
from .log_analytics_entity_type_summary import LogAnalyticsEntityTypeSummary
from .log_analytics_extended_field import LogAnalyticsExtendedField
from .log_analytics_field import LogAnalyticsField
from .log_analytics_field_collection import LogAnalyticsFieldCollection
from .log_analytics_field_summary import LogAnalyticsFieldSummary
from .log_analytics_import_custom_change_list import LogAnalyticsImportCustomChangeList
from .log_analytics_import_custom_content import LogAnalyticsImportCustomContent
from .log_analytics_label import LogAnalyticsLabel
from .log_analytics_label_alias import LogAnalyticsLabelAlias
from .log_analytics_label_collection import LogAnalyticsLabelCollection
from .log_analytics_label_definition import LogAnalyticsLabelDefinition
from .log_analytics_label_operator import LogAnalyticsLabelOperator
from .log_analytics_label_operator_collection import LogAnalyticsLabelOperatorCollection
from .log_analytics_label_summary import LogAnalyticsLabelSummary
from .log_analytics_label_view import LogAnalyticsLabelView
from .log_analytics_log_group import LogAnalyticsLogGroup
from .log_analytics_log_group_summary import LogAnalyticsLogGroupSummary
from .log_analytics_log_group_summary_collection import LogAnalyticsLogGroupSummaryCollection
from .log_analytics_lookup import LogAnalyticsLookup
from .log_analytics_meta_function import LogAnalyticsMetaFunction
from .log_analytics_meta_function_argument import LogAnalyticsMetaFunctionArgument
from .log_analytics_meta_function_collection import LogAnalyticsMetaFunctionCollection
from .log_analytics_meta_source_type import LogAnalyticsMetaSourceType
from .log_analytics_meta_source_type_collection import LogAnalyticsMetaSourceTypeCollection
from .log_analytics_metric import LogAnalyticsMetric
from .log_analytics_object_collection_rule import LogAnalyticsObjectCollectionRule
from .log_analytics_object_collection_rule_collection import LogAnalyticsObjectCollectionRuleCollection
from .log_analytics_object_collection_rule_summary import LogAnalyticsObjectCollectionRuleSummary
from .log_analytics_parameter import LogAnalyticsParameter
from .log_analytics_parser import LogAnalyticsParser
from .log_analytics_parser_collection import LogAnalyticsParserCollection
from .log_analytics_parser_field import LogAnalyticsParserField
from .log_analytics_parser_filter import LogAnalyticsParserFilter
from .log_analytics_parser_function import LogAnalyticsParserFunction
from .log_analytics_parser_function_collection import LogAnalyticsParserFunctionCollection
from .log_analytics_parser_function_parameter import LogAnalyticsParserFunctionParameter
from .log_analytics_parser_meta_plugin import LogAnalyticsParserMetaPlugin
from .log_analytics_parser_meta_plugin_collection import LogAnalyticsParserMetaPluginCollection
from .log_analytics_parser_meta_plugin_parameter import LogAnalyticsParserMetaPluginParameter
from .log_analytics_parser_summary import LogAnalyticsParserSummary
from .log_analytics_pattern_filter import LogAnalyticsPatternFilter
from .log_analytics_source import LogAnalyticsSource
from .log_analytics_source_collection import LogAnalyticsSourceCollection
from .log_analytics_source_data_filter import LogAnalyticsSourceDataFilter
from .log_analytics_source_entity_type import LogAnalyticsSourceEntityType
from .log_analytics_source_extended_field_definition import LogAnalyticsSourceExtendedFieldDefinition
from .log_analytics_source_extended_field_definition_collection import LogAnalyticsSourceExtendedFieldDefinitionCollection
from .log_analytics_source_function import LogAnalyticsSourceFunction
from .log_analytics_source_label_condition import LogAnalyticsSourceLabelCondition
from .log_analytics_source_metadata_field import LogAnalyticsSourceMetadataField
from .log_analytics_source_metric import LogAnalyticsSourceMetric
from .log_analytics_source_pattern import LogAnalyticsSourcePattern
from .log_analytics_source_pattern_collection import LogAnalyticsSourcePatternCollection
from .log_analytics_source_summary import LogAnalyticsSourceSummary
from .log_analytics_summary import LogAnalyticsSummary
from .log_group_summary_report import LogGroupSummaryReport
from .lookup_command_descriptor import LookupCommandDescriptor
from .lookup_field import LookupField
from .macro_command_descriptor import MacroCommandDescriptor
from .match_info import MatchInfo
from .multi_search_command_descriptor import MultiSearchCommandDescriptor
from .namespace import Namespace
from .namespace_collection import NamespaceCollection
from .namespace_summary import NamespaceSummary
from .out_of_box_entity_type_details import OutOfBoxEntityTypeDetails
from .parse_query_details import ParseQueryDetails
from .parse_query_output import ParseQueryOutput
from .parsed_content import ParsedContent
from .parsed_field import ParsedField
from .parser_summary_report import ParserSummaryReport
from .parser_test_result import ParserTestResult
from .property_override import PropertyOverride
from .purge_action import PurgeAction
from .purge_storage_data_details import PurgeStorageDataDetails
from .query import Query
from .query_aggregation import QueryAggregation
from .query_details import QueryDetails
from .query_work_request import QueryWorkRequest
from .query_work_request_collection import QueryWorkRequestCollection
from .query_work_request_resource import QueryWorkRequestResource
from .query_work_request_summary import QueryWorkRequestSummary
from .recall_archived_data_details import RecallArchivedDataDetails
from .regex_command_descriptor import RegexCommandDescriptor
from .regex_match_result import RegexMatchResult
from .register_entity_types_details import RegisterEntityTypesDetails
from .release_recalled_data_details import ReleaseRecalledDataDetails
from .remove_entity_associations_details import RemoveEntityAssociationsDetails
from .rename_command_descriptor import RenameCommandDescriptor
from .result_column import ResultColumn
from .schedule import Schedule
from .scheduled_task import ScheduledTask
from .scheduled_task_collection import ScheduledTaskCollection
from .scheduled_task_summary import ScheduledTaskSummary
from .scheduler_resource import SchedulerResource
from .scope_filter import ScopeFilter
from .search_command_descriptor import SearchCommandDescriptor
from .search_lookup_command_descriptor import SearchLookupCommandDescriptor
from .service_tenancy import ServiceTenancy
from .sort_command_descriptor import SortCommandDescriptor
from .sort_field import SortField
from .source_mapping_response import SourceMappingResponse
from .source_summary_report import SourceSummaryReport
from .source_validate_details import SourceValidateDetails
from .source_validate_results import SourceValidateResults
from .stats_command_descriptor import StatsCommandDescriptor
from .status_summary import StatusSummary
from .step_info import StepInfo
from .storage import Storage
from .storage_usage import StorageUsage
from .storage_work_request import StorageWorkRequest
from .storage_work_request_collection import StorageWorkRequestCollection
from .storage_work_request_summary import StorageWorkRequestSummary
from .stream_action import StreamAction
from .string_list_details import StringListDetails
from .success import Success
from .suggest_details import SuggestDetails
from .suggest_output import SuggestOutput
from .tail_command_descriptor import TailCommandDescriptor
from .test_parser_payload_details import TestParserPayloadDetails
from .time_column import TimeColumn
from .time_compare_command_descriptor import TimeCompareCommandDescriptor
from .time_range import TimeRange
from .time_stats_command_descriptor import TimeStatsCommandDescriptor
from .timezone_collection import TimezoneCollection
from .top_command_descriptor import TopCommandDescriptor
from .trend_column import TrendColumn
from .ui_parser_test_metadata import UiParserTestMetadata
from .update_log_analytics_entity_details import UpdateLogAnalyticsEntityDetails
from .update_log_analytics_entity_type_details import UpdateLogAnalyticsEntityTypeDetails
from .update_log_analytics_log_group_details import UpdateLogAnalyticsLogGroupDetails
from .update_log_analytics_object_collection_rule_details import UpdateLogAnalyticsObjectCollectionRuleDetails
from .update_scheduled_task_details import UpdateScheduledTaskDetails
from .update_storage_details import UpdateStorageDetails
from .upload import Upload
from .upload_collection import UploadCollection
from .upload_file_collection import UploadFileCollection
from .upload_file_status import UploadFileStatus
from .upload_file_summary import UploadFileSummary
from .upload_summary import UploadSummary
from .upload_warning_collection import UploadWarningCollection
from .upload_warning_summary import UploadWarningSummary
from .upsert_log_analytics_association import UpsertLogAnalyticsAssociation
from .upsert_log_analytics_association_details import UpsertLogAnalyticsAssociationDetails
from .upsert_log_analytics_field_details import UpsertLogAnalyticsFieldDetails
from .upsert_log_analytics_label_details import UpsertLogAnalyticsLabelDetails
from .upsert_log_analytics_parser_details import UpsertLogAnalyticsParserDetails
from .upsert_log_analytics_source_details import UpsertLogAnalyticsSourceDetails
from .usage_status_item import UsageStatusItem
from .verify_output import VerifyOutput
from .violation import Violation
from .where_command_descriptor import WhereCommandDescriptor
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log import WorkRequestLog
from .work_request_log_collection import WorkRequestLogCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for log_analytics services.
log_analytics_type_mapping = {
    "AbstractColumn": AbstractColumn,
    "AbstractCommandDescriptor": AbstractCommandDescriptor,
    "AbstractField": AbstractField,
    "AbstractParserTestResultLogEntry": AbstractParserTestResultLogEntry,
    "AbstractParserTestResultLogLine": AbstractParserTestResultLogLine,
    "Action": Action,
    "AddEntityAssociationDetails": AddEntityAssociationDetails,
    "AddFieldsCommandDescriptor": AddFieldsCommandDescriptor,
    "AgentUpload": AgentUpload,
    "ArchivingConfiguration": ArchivingConfiguration,
    "Argument": Argument,
    "AssociationSummaryReport": AssociationSummaryReport,
    "Attribute": Attribute,
    "AutoLookups": AutoLookups,
    "BottomCommandDescriptor": BottomCommandDescriptor,
    "BucketCommandDescriptor": BucketCommandDescriptor,
    "BucketRange": BucketRange,
    "ChangeLogAnalyticsEntityCompartmentDetails": ChangeLogAnalyticsEntityCompartmentDetails,
    "ChangeLogAnalyticsLogGroupCompartmentDetails": ChangeLogAnalyticsLogGroupCompartmentDetails,
    "ChangeLogAnalyticsObjectCollectionRuleCompartmentDetails": ChangeLogAnalyticsObjectCollectionRuleCompartmentDetails,
    "ChangeScheduledTaskCompartmentDetails": ChangeScheduledTaskCompartmentDetails,
    "CharEncodingCollection": CharEncodingCollection,
    "ChartColumn": ChartColumn,
    "ChartDataColumn": ChartDataColumn,
    "ClassifyColumn": ClassifyColumn,
    "ClassifyCommandDescriptor": ClassifyCommandDescriptor,
    "ClusterCommandDescriptor": ClusterCommandDescriptor,
    "ClusterCompareCommandDescriptor": ClusterCompareCommandDescriptor,
    "ClusterDetailsCommandDescriptor": ClusterDetailsCommandDescriptor,
    "ClusterSplitCommandDescriptor": ClusterSplitCommandDescriptor,
    "Column": Column,
    "ColumnName": ColumnName,
    "ColumnNameCollection": ColumnNameCollection,
    "CommandDescriptor": CommandDescriptor,
    "CreateAccelerationTaskDetails": CreateAccelerationTaskDetails,
    "CreateLogAnalyticsEntityDetails": CreateLogAnalyticsEntityDetails,
    "CreateLogAnalyticsEntityTypeDetails": CreateLogAnalyticsEntityTypeDetails,
    "CreateLogAnalyticsLogGroupDetails": CreateLogAnalyticsLogGroupDetails,
    "CreateLogAnalyticsObjectCollectionRuleDetails": CreateLogAnalyticsObjectCollectionRuleDetails,
    "CreateNamespaceDetails": CreateNamespaceDetails,
    "CreateScheduledTaskDetails": CreateScheduledTaskDetails,
    "CreateStandardTaskDetails": CreateStandardTaskDetails,
    "CronSchedule": CronSchedule,
    "DeleteCommandDescriptor": DeleteCommandDescriptor,
    "DeleteLogAnalyticsAssociation": DeleteLogAnalyticsAssociation,
    "DeleteLogAnalyticsAssociationDetails": DeleteLogAnalyticsAssociationDetails,
    "DeltaCommandDescriptor": DeltaCommandDescriptor,
    "DemoModeCommandDescriptor": DemoModeCommandDescriptor,
    "DistinctCommandDescriptor": DistinctCommandDescriptor,
    "EfdRegexResult": EfdRegexResult,
    "EntityTypeProperty": EntityTypeProperty,
    "ErrorDetails": ErrorDetails,
    "EstimatePurgeDataSizeDetails": EstimatePurgeDataSizeDetails,
    "EstimatePurgeDataSizeResult": EstimatePurgeDataSizeResult,
    "EvalCommandDescriptor": EvalCommandDescriptor,
    "EventStatsCommandDescriptor": EventStatsCommandDescriptor,
    "ExportContent": ExportContent,
    "ExportDetails": ExportDetails,
    "ExtendedFieldsValidationResult": ExtendedFieldsValidationResult,
    "ExtractCommandDescriptor": ExtractCommandDescriptor,
    "ExtractLogFieldResults": ExtractLogFieldResults,
    "ExtractLogHeaderDetails": ExtractLogHeaderDetails,
    "ExtractLogHeaderResults": ExtractLogHeaderResults,
    "Field": Field,
    "FieldArgument": FieldArgument,
    "FieldMap": FieldMap,
    "FieldSummaryCommandDescriptor": FieldSummaryCommandDescriptor,
    "FieldSummaryReport": FieldSummaryReport,
    "FieldValue": FieldValue,
    "FieldsAddRemoveField": FieldsAddRemoveField,
    "FieldsCommandDescriptor": FieldsCommandDescriptor,
    "FileValidationResponse": FileValidationResponse,
    "Filter": Filter,
    "FilterDetails": FilterDetails,
    "FilterOutput": FilterOutput,
    "FixedFrequencySchedule": FixedFrequencySchedule,
    "FunctionField": FunctionField,
    "GenerateAgentObjectNameDetails": GenerateAgentObjectNameDetails,
    "HeadCommandDescriptor": HeadCommandDescriptor,
    "HighlightCommandDescriptor": HighlightCommandDescriptor,
    "HighlightRowsCommandDescriptor": HighlightRowsCommandDescriptor,
    "Indexes": Indexes,
    "LabelNames": LabelNames,
    "LabelPriority": LabelPriority,
    "LabelPriorityCollection": LabelPriorityCollection,
    "LabelSourceCollection": LabelSourceCollection,
    "LabelSourceSummary": LabelSourceSummary,
    "LabelSummaryReport": LabelSummaryReport,
    "LinkCommandDescriptor": LinkCommandDescriptor,
    "LinkDetailsCommandDescriptor": LinkDetailsCommandDescriptor,
    "LiteralArgument": LiteralArgument,
    "LogAnalytics": LogAnalytics,
    "LogAnalyticsAssociatedEntity": LogAnalyticsAssociatedEntity,
    "LogAnalyticsAssociatedEntityCollection": LogAnalyticsAssociatedEntityCollection,
    "LogAnalyticsAssociation": LogAnalyticsAssociation,
    "LogAnalyticsAssociationCollection": LogAnalyticsAssociationCollection,
    "LogAnalyticsAssociationParameter": LogAnalyticsAssociationParameter,
    "LogAnalyticsAssociationParameterCollection": LogAnalyticsAssociationParameterCollection,
    "LogAnalyticsCollectionWarning": LogAnalyticsCollectionWarning,
    "LogAnalyticsConfigWorkRequest": LogAnalyticsConfigWorkRequest,
    "LogAnalyticsConfigWorkRequestCollection": LogAnalyticsConfigWorkRequestCollection,
    "LogAnalyticsConfigWorkRequestPayload": LogAnalyticsConfigWorkRequestPayload,
    "LogAnalyticsConfigWorkRequestSummary": LogAnalyticsConfigWorkRequestSummary,
    "LogAnalyticsEntity": LogAnalyticsEntity,
    "LogAnalyticsEntityCollection": LogAnalyticsEntityCollection,
    "LogAnalyticsEntitySummary": LogAnalyticsEntitySummary,
    "LogAnalyticsEntitySummaryReport": LogAnalyticsEntitySummaryReport,
    "LogAnalyticsEntityType": LogAnalyticsEntityType,
    "LogAnalyticsEntityTypeCollection": LogAnalyticsEntityTypeCollection,
    "LogAnalyticsEntityTypeSummary": LogAnalyticsEntityTypeSummary,
    "LogAnalyticsExtendedField": LogAnalyticsExtendedField,
    "LogAnalyticsField": LogAnalyticsField,
    "LogAnalyticsFieldCollection": LogAnalyticsFieldCollection,
    "LogAnalyticsFieldSummary": LogAnalyticsFieldSummary,
    "LogAnalyticsImportCustomChangeList": LogAnalyticsImportCustomChangeList,
    "LogAnalyticsImportCustomContent": LogAnalyticsImportCustomContent,
    "LogAnalyticsLabel": LogAnalyticsLabel,
    "LogAnalyticsLabelAlias": LogAnalyticsLabelAlias,
    "LogAnalyticsLabelCollection": LogAnalyticsLabelCollection,
    "LogAnalyticsLabelDefinition": LogAnalyticsLabelDefinition,
    "LogAnalyticsLabelOperator": LogAnalyticsLabelOperator,
    "LogAnalyticsLabelOperatorCollection": LogAnalyticsLabelOperatorCollection,
    "LogAnalyticsLabelSummary": LogAnalyticsLabelSummary,
    "LogAnalyticsLabelView": LogAnalyticsLabelView,
    "LogAnalyticsLogGroup": LogAnalyticsLogGroup,
    "LogAnalyticsLogGroupSummary": LogAnalyticsLogGroupSummary,
    "LogAnalyticsLogGroupSummaryCollection": LogAnalyticsLogGroupSummaryCollection,
    "LogAnalyticsLookup": LogAnalyticsLookup,
    "LogAnalyticsMetaFunction": LogAnalyticsMetaFunction,
    "LogAnalyticsMetaFunctionArgument": LogAnalyticsMetaFunctionArgument,
    "LogAnalyticsMetaFunctionCollection": LogAnalyticsMetaFunctionCollection,
    "LogAnalyticsMetaSourceType": LogAnalyticsMetaSourceType,
    "LogAnalyticsMetaSourceTypeCollection": LogAnalyticsMetaSourceTypeCollection,
    "LogAnalyticsMetric": LogAnalyticsMetric,
    "LogAnalyticsObjectCollectionRule": LogAnalyticsObjectCollectionRule,
    "LogAnalyticsObjectCollectionRuleCollection": LogAnalyticsObjectCollectionRuleCollection,
    "LogAnalyticsObjectCollectionRuleSummary": LogAnalyticsObjectCollectionRuleSummary,
    "LogAnalyticsParameter": LogAnalyticsParameter,
    "LogAnalyticsParser": LogAnalyticsParser,
    "LogAnalyticsParserCollection": LogAnalyticsParserCollection,
    "LogAnalyticsParserField": LogAnalyticsParserField,
    "LogAnalyticsParserFilter": LogAnalyticsParserFilter,
    "LogAnalyticsParserFunction": LogAnalyticsParserFunction,
    "LogAnalyticsParserFunctionCollection": LogAnalyticsParserFunctionCollection,
    "LogAnalyticsParserFunctionParameter": LogAnalyticsParserFunctionParameter,
    "LogAnalyticsParserMetaPlugin": LogAnalyticsParserMetaPlugin,
    "LogAnalyticsParserMetaPluginCollection": LogAnalyticsParserMetaPluginCollection,
    "LogAnalyticsParserMetaPluginParameter": LogAnalyticsParserMetaPluginParameter,
    "LogAnalyticsParserSummary": LogAnalyticsParserSummary,
    "LogAnalyticsPatternFilter": LogAnalyticsPatternFilter,
    "LogAnalyticsSource": LogAnalyticsSource,
    "LogAnalyticsSourceCollection": LogAnalyticsSourceCollection,
    "LogAnalyticsSourceDataFilter": LogAnalyticsSourceDataFilter,
    "LogAnalyticsSourceEntityType": LogAnalyticsSourceEntityType,
    "LogAnalyticsSourceExtendedFieldDefinition": LogAnalyticsSourceExtendedFieldDefinition,
    "LogAnalyticsSourceExtendedFieldDefinitionCollection": LogAnalyticsSourceExtendedFieldDefinitionCollection,
    "LogAnalyticsSourceFunction": LogAnalyticsSourceFunction,
    "LogAnalyticsSourceLabelCondition": LogAnalyticsSourceLabelCondition,
    "LogAnalyticsSourceMetadataField": LogAnalyticsSourceMetadataField,
    "LogAnalyticsSourceMetric": LogAnalyticsSourceMetric,
    "LogAnalyticsSourcePattern": LogAnalyticsSourcePattern,
    "LogAnalyticsSourcePatternCollection": LogAnalyticsSourcePatternCollection,
    "LogAnalyticsSourceSummary": LogAnalyticsSourceSummary,
    "LogAnalyticsSummary": LogAnalyticsSummary,
    "LogGroupSummaryReport": LogGroupSummaryReport,
    "LookupCommandDescriptor": LookupCommandDescriptor,
    "LookupField": LookupField,
    "MacroCommandDescriptor": MacroCommandDescriptor,
    "MatchInfo": MatchInfo,
    "MultiSearchCommandDescriptor": MultiSearchCommandDescriptor,
    "Namespace": Namespace,
    "NamespaceCollection": NamespaceCollection,
    "NamespaceSummary": NamespaceSummary,
    "OutOfBoxEntityTypeDetails": OutOfBoxEntityTypeDetails,
    "ParseQueryDetails": ParseQueryDetails,
    "ParseQueryOutput": ParseQueryOutput,
    "ParsedContent": ParsedContent,
    "ParsedField": ParsedField,
    "ParserSummaryReport": ParserSummaryReport,
    "ParserTestResult": ParserTestResult,
    "PropertyOverride": PropertyOverride,
    "PurgeAction": PurgeAction,
    "PurgeStorageDataDetails": PurgeStorageDataDetails,
    "Query": Query,
    "QueryAggregation": QueryAggregation,
    "QueryDetails": QueryDetails,
    "QueryWorkRequest": QueryWorkRequest,
    "QueryWorkRequestCollection": QueryWorkRequestCollection,
    "QueryWorkRequestResource": QueryWorkRequestResource,
    "QueryWorkRequestSummary": QueryWorkRequestSummary,
    "RecallArchivedDataDetails": RecallArchivedDataDetails,
    "RegexCommandDescriptor": RegexCommandDescriptor,
    "RegexMatchResult": RegexMatchResult,
    "RegisterEntityTypesDetails": RegisterEntityTypesDetails,
    "ReleaseRecalledDataDetails": ReleaseRecalledDataDetails,
    "RemoveEntityAssociationsDetails": RemoveEntityAssociationsDetails,
    "RenameCommandDescriptor": RenameCommandDescriptor,
    "ResultColumn": ResultColumn,
    "Schedule": Schedule,
    "ScheduledTask": ScheduledTask,
    "ScheduledTaskCollection": ScheduledTaskCollection,
    "ScheduledTaskSummary": ScheduledTaskSummary,
    "SchedulerResource": SchedulerResource,
    "ScopeFilter": ScopeFilter,
    "SearchCommandDescriptor": SearchCommandDescriptor,
    "SearchLookupCommandDescriptor": SearchLookupCommandDescriptor,
    "ServiceTenancy": ServiceTenancy,
    "SortCommandDescriptor": SortCommandDescriptor,
    "SortField": SortField,
    "SourceMappingResponse": SourceMappingResponse,
    "SourceSummaryReport": SourceSummaryReport,
    "SourceValidateDetails": SourceValidateDetails,
    "SourceValidateResults": SourceValidateResults,
    "StatsCommandDescriptor": StatsCommandDescriptor,
    "StatusSummary": StatusSummary,
    "StepInfo": StepInfo,
    "Storage": Storage,
    "StorageUsage": StorageUsage,
    "StorageWorkRequest": StorageWorkRequest,
    "StorageWorkRequestCollection": StorageWorkRequestCollection,
    "StorageWorkRequestSummary": StorageWorkRequestSummary,
    "StreamAction": StreamAction,
    "StringListDetails": StringListDetails,
    "Success": Success,
    "SuggestDetails": SuggestDetails,
    "SuggestOutput": SuggestOutput,
    "TailCommandDescriptor": TailCommandDescriptor,
    "TestParserPayloadDetails": TestParserPayloadDetails,
    "TimeColumn": TimeColumn,
    "TimeCompareCommandDescriptor": TimeCompareCommandDescriptor,
    "TimeRange": TimeRange,
    "TimeStatsCommandDescriptor": TimeStatsCommandDescriptor,
    "TimezoneCollection": TimezoneCollection,
    "TopCommandDescriptor": TopCommandDescriptor,
    "TrendColumn": TrendColumn,
    "UiParserTestMetadata": UiParserTestMetadata,
    "UpdateLogAnalyticsEntityDetails": UpdateLogAnalyticsEntityDetails,
    "UpdateLogAnalyticsEntityTypeDetails": UpdateLogAnalyticsEntityTypeDetails,
    "UpdateLogAnalyticsLogGroupDetails": UpdateLogAnalyticsLogGroupDetails,
    "UpdateLogAnalyticsObjectCollectionRuleDetails": UpdateLogAnalyticsObjectCollectionRuleDetails,
    "UpdateScheduledTaskDetails": UpdateScheduledTaskDetails,
    "UpdateStorageDetails": UpdateStorageDetails,
    "Upload": Upload,
    "UploadCollection": UploadCollection,
    "UploadFileCollection": UploadFileCollection,
    "UploadFileStatus": UploadFileStatus,
    "UploadFileSummary": UploadFileSummary,
    "UploadSummary": UploadSummary,
    "UploadWarningCollection": UploadWarningCollection,
    "UploadWarningSummary": UploadWarningSummary,
    "UpsertLogAnalyticsAssociation": UpsertLogAnalyticsAssociation,
    "UpsertLogAnalyticsAssociationDetails": UpsertLogAnalyticsAssociationDetails,
    "UpsertLogAnalyticsFieldDetails": UpsertLogAnalyticsFieldDetails,
    "UpsertLogAnalyticsLabelDetails": UpsertLogAnalyticsLabelDetails,
    "UpsertLogAnalyticsParserDetails": UpsertLogAnalyticsParserDetails,
    "UpsertLogAnalyticsSourceDetails": UpsertLogAnalyticsSourceDetails,
    "UsageStatusItem": UsageStatusItem,
    "VerifyOutput": VerifyOutput,
    "Violation": Violation,
    "WhereCommandDescriptor": WhereCommandDescriptor,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLog": WorkRequestLog,
    "WorkRequestLogCollection": WorkRequestLogCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LocalPeeringGateway(object):
    """
    A local peering gateway (LPG) is an object on a VCN that lets that VCN peer
    with another VCN in the same region. *Peering* means that the two VCNs can
    communicate using private IP addresses, but without the traffic traversing the
    internet or routing through your on-premises network. For more information,
    see `VCN Peering`__.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
    talk to an administrator. If you're an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you
    supply string values using the API.

    __ https://docs.cloud.oracle.com/Content/Network/Tasks/VCNpeering.htm
    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a LocalPeeringGateway.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a LocalPeeringGateway.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a LocalPeeringGateway.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a LocalPeeringGateway.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the peering_status property of a LocalPeeringGateway.
    #: This constant has a value of "INVALID"
    PEERING_STATUS_INVALID = "INVALID"

    #: A constant which can be used with the peering_status property of a LocalPeeringGateway.
    #: This constant has a value of "NEW"
    PEERING_STATUS_NEW = "NEW"

    #: A constant which can be used with the peering_status property of a LocalPeeringGateway.
    #: This constant has a value of "PEERED"
    PEERING_STATUS_PEERED = "PEERED"

    #: A constant which can be used with the peering_status property of a LocalPeeringGateway.
    #: This constant has a value of "PENDING"
    PEERING_STATUS_PENDING = "PENDING"

    #: A constant which can be used with the peering_status property of a LocalPeeringGateway.
    #: This constant has a value of "REVOKED"
    PEERING_STATUS_REVOKED = "REVOKED"

    def __init__(self, **kwargs):
        """
        Initializes a new LocalPeeringGateway object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this LocalPeeringGateway.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this LocalPeeringGateway.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this LocalPeeringGateway.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this LocalPeeringGateway.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this LocalPeeringGateway.
        :type id: str

        :param is_cross_tenancy_peering:
            The value to assign to the is_cross_tenancy_peering property of this LocalPeeringGateway.
        :type is_cross_tenancy_peering: bool

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this LocalPeeringGateway.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param peer_advertised_cidr:
            The value to assign to the peer_advertised_cidr property of this LocalPeeringGateway.
        :type peer_advertised_cidr: str

        :param peer_advertised_cidr_details:
            The value to assign to the peer_advertised_cidr_details property of this LocalPeeringGateway.
        :type peer_advertised_cidr_details: list[str]

        :param peering_status:
            The value to assign to the peering_status property of this LocalPeeringGateway.
            Allowed values for this property are: "INVALID", "NEW", "PEERED", "PENDING", "REVOKED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type peering_status: str

        :param peering_status_details:
            The value to assign to the peering_status_details property of this LocalPeeringGateway.
        :type peering_status_details: str

        :param route_table_id:
            The value to assign to the route_table_id property of this LocalPeeringGateway.
        :type route_table_id: str

        :param time_created:
            The value to assign to the time_created property of this LocalPeeringGateway.
        :type time_created: datetime

        :param vcn_id:
            The value to assign to the vcn_id property of this LocalPeeringGateway.
        :type vcn_id: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'is_cross_tenancy_peering': 'bool',
            'lifecycle_state': 'str',
            'peer_advertised_cidr': 'str',
            'peer_advertised_cidr_details': 'list[str]',
            'peering_status': 'str',
            'peering_status_details': 'str',
            'route_table_id': 'str',
            'time_created': 'datetime',
            'vcn_id': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'is_cross_tenancy_peering': 'isCrossTenancyPeering',
            'lifecycle_state': 'lifecycleState',
            'peer_advertised_cidr': 'peerAdvertisedCidr',
            'peer_advertised_cidr_details': 'peerAdvertisedCidrDetails',
            'peering_status': 'peeringStatus',
            'peering_status_details': 'peeringStatusDetails',
            'route_table_id': 'routeTableId',
            'time_created': 'timeCreated',
            'vcn_id': 'vcnId'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._is_cross_tenancy_peering = None
        self._lifecycle_state = None
        self._peer_advertised_cidr = None
        self._peer_advertised_cidr_details = None
        self._peering_status = None
        self._peering_status_details = None
        self._route_table_id = None
        self._time_created = None
        self._vcn_id = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this LocalPeeringGateway.
        The OCID of the compartment containing the LPG.


        :return: The compartment_id of this LocalPeeringGateway.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this LocalPeeringGateway.
        The OCID of the compartment containing the LPG.


        :param compartment_id: The compartment_id of this LocalPeeringGateway.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this LocalPeeringGateway.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this LocalPeeringGateway.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this LocalPeeringGateway.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this LocalPeeringGateway.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this LocalPeeringGateway.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :return: The display_name of this LocalPeeringGateway.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this LocalPeeringGateway.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :param display_name: The display_name of this LocalPeeringGateway.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this LocalPeeringGateway.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this LocalPeeringGateway.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this LocalPeeringGateway.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this LocalPeeringGateway.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this LocalPeeringGateway.
        The LPG's Oracle ID (OCID).


        :return: The id of this LocalPeeringGateway.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LocalPeeringGateway.
        The LPG's Oracle ID (OCID).


        :param id: The id of this LocalPeeringGateway.
        :type: str
        """
        self._id = id

    @property
    def is_cross_tenancy_peering(self):
        """
        **[Required]** Gets the is_cross_tenancy_peering of this LocalPeeringGateway.
        Whether the VCN at the other end of the peering is in a different tenancy.

        Example: `false`


        :return: The is_cross_tenancy_peering of this LocalPeeringGateway.
        :rtype: bool
        """
        return self._is_cross_tenancy_peering

    @is_cross_tenancy_peering.setter
    def is_cross_tenancy_peering(self, is_cross_tenancy_peering):
        """
        Sets the is_cross_tenancy_peering of this LocalPeeringGateway.
        Whether the VCN at the other end of the peering is in a different tenancy.

        Example: `false`


        :param is_cross_tenancy_peering: The is_cross_tenancy_peering of this LocalPeeringGateway.
        :type: bool
        """
        self._is_cross_tenancy_peering = is_cross_tenancy_peering

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this LocalPeeringGateway.
        The LPG's current lifecycle state.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this LocalPeeringGateway.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this LocalPeeringGateway.
        The LPG's current lifecycle state.


        :param lifecycle_state: The lifecycle_state of this LocalPeeringGateway.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def peer_advertised_cidr(self):
        """
        Gets the peer_advertised_cidr of this LocalPeeringGateway.
        The smallest aggregate CIDR that contains all the CIDR routes advertised by the VCN
        at the other end of the peering from this LPG. See `peerAdvertisedCidrDetails` for
        the individual CIDRs. The value is `null` if the LPG is not peered.

        Example: `192.168.0.0/16`, or if aggregated with `172.16.0.0/24` then `128.0.0.0/1`


        :return: The peer_advertised_cidr of this LocalPeeringGateway.
        :rtype: str
        """
        return self._peer_advertised_cidr

    @peer_advertised_cidr.setter
    def peer_advertised_cidr(self, peer_advertised_cidr):
        """
        Sets the peer_advertised_cidr of this LocalPeeringGateway.
        The smallest aggregate CIDR that contains all the CIDR routes advertised by the VCN
        at the other end of the peering from this LPG. See `peerAdvertisedCidrDetails` for
        the individual CIDRs. The value is `null` if the LPG is not peered.

        Example: `192.168.0.0/16`, or if aggregated with `172.16.0.0/24` then `128.0.0.0/1`


        :param peer_advertised_cidr: The peer_advertised_cidr of this LocalPeeringGateway.
        :type: str
        """
        self._peer_advertised_cidr = peer_advertised_cidr

    @property
    def peer_advertised_cidr_details(self):
        """
        Gets the peer_advertised_cidr_details of this LocalPeeringGateway.
        The specific ranges of IP addresses available on or via the VCN at the other
        end of the peering from this LPG. The value is `null` if the LPG is not peered.
        You can use these as destination CIDRs for route rules to route a subnet's
        traffic to this LPG.

        Example: [`192.168.0.0/16`, `172.16.0.0/24`]


        :return: The peer_advertised_cidr_details of this LocalPeeringGateway.
        :rtype: list[str]
        """
        return self._peer_advertised_cidr_details

    @peer_advertised_cidr_details.setter
    def peer_advertised_cidr_details(self, peer_advertised_cidr_details):
        """
        Sets the peer_advertised_cidr_details of this LocalPeeringGateway.
        The specific ranges of IP addresses available on or via the VCN at the other
        end of the peering from this LPG. The value is `null` if the LPG is not peered.
        You can use these as destination CIDRs for route rules to route a subnet's
        traffic to this LPG.

        Example: [`192.168.0.0/16`, `172.16.0.0/24`]


        :param peer_advertised_cidr_details: The peer_advertised_cidr_details of this LocalPeeringGateway.
        :type: list[str]
        """
        self._peer_advertised_cidr_details = peer_advertised_cidr_details

    @property
    def peering_status(self):
        """
        **[Required]** Gets the peering_status of this LocalPeeringGateway.
        Whether the LPG is peered with another LPG. `NEW` means the LPG has not yet been
        peered. `PENDING` means the peering is being established. `REVOKED` means the
        LPG at the other end of the peering has been deleted.

        Allowed values for this property are: "INVALID", "NEW", "PEERED", "PENDING", "REVOKED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The peering_status of this LocalPeeringGateway.
        :rtype: str
        """
        return self._peering_status

    @peering_status.setter
    def peering_status(self, peering_status):
        """
        Sets the peering_status of this LocalPeeringGateway.
        Whether the LPG is peered with another LPG. `NEW` means the LPG has not yet been
        peered. `PENDING` means the peering is being established. `REVOKED` means the
        LPG at the other end of the peering has been deleted.


        :param peering_status: The peering_status of this LocalPeeringGateway.
        :type: str
        """
        allowed_values = ["INVALID", "NEW", "PEERED", "PENDING", "REVOKED"]
        if not value_allowed_none_or_none_sentinel(peering_status, allowed_values):
            peering_status = 'UNKNOWN_ENUM_VALUE'
        self._peering_status = peering_status

    @property
    def peering_status_details(self):
        """
        Gets the peering_status_details of this LocalPeeringGateway.
        Additional information regarding the peering status, if applicable.


        :return: The peering_status_details of this LocalPeeringGateway.
        :rtype: str
        """
        return self._peering_status_details

    @peering_status_details.setter
    def peering_status_details(self, peering_status_details):
        """
        Sets the peering_status_details of this LocalPeeringGateway.
        Additional information regarding the peering status, if applicable.


        :param peering_status_details: The peering_status_details of this LocalPeeringGateway.
        :type: str
        """
        self._peering_status_details = peering_status_details

    @property
    def route_table_id(self):
        """
        Gets the route_table_id of this LocalPeeringGateway.
        The OCID of the route table the LPG is using.

        For information about why you would associate a route table with an LPG, see
        `Transit Routing: Access to Multiple VCNs in Same Region`__.

        __ https://docs.cloud.oracle.com/Content/Network/Tasks/transitrouting.htm


        :return: The route_table_id of this LocalPeeringGateway.
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """
        Sets the route_table_id of this LocalPeeringGateway.
        The OCID of the route table the LPG is using.

        For information about why you would associate a route table with an LPG, see
        `Transit Routing: Access to Multiple VCNs in Same Region`__.

        __ https://docs.cloud.oracle.com/Content/Network/Tasks/transitrouting.htm


        :param route_table_id: The route_table_id of this LocalPeeringGateway.
        :type: str
        """
        self._route_table_id = route_table_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this LocalPeeringGateway.
        The date and time the LPG was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this LocalPeeringGateway.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this LocalPeeringGateway.
        The date and time the LPG was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this LocalPeeringGateway.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def vcn_id(self):
        """
        **[Required]** Gets the vcn_id of this LocalPeeringGateway.
        The OCID of the VCN the LPG belongs to.


        :return: The vcn_id of this LocalPeeringGateway.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this LocalPeeringGateway.
        The OCID of the VCN the LPG belongs to.


        :param vcn_id: The vcn_id of this LocalPeeringGateway.
        :type: str
        """
        self._vcn_id = vcn_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImageMemoryConstraints(object):
    """
    For a flexible image and shape, the amount of memory supported for instances that use this image.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ImageMemoryConstraints object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param min_in_gbs:
            The value to assign to the min_in_gbs property of this ImageMemoryConstraints.
        :type min_in_gbs: int

        :param max_in_gbs:
            The value to assign to the max_in_gbs property of this ImageMemoryConstraints.
        :type max_in_gbs: int

        """
        self.swagger_types = {
            'min_in_gbs': 'int',
            'max_in_gbs': 'int'
        }

        self.attribute_map = {
            'min_in_gbs': 'minInGBs',
            'max_in_gbs': 'maxInGBs'
        }

        self._min_in_gbs = None
        self._max_in_gbs = None

    @property
    def min_in_gbs(self):
        """
        Gets the min_in_gbs of this ImageMemoryConstraints.
        The minimum amount of memory, in gigabytes.


        :return: The min_in_gbs of this ImageMemoryConstraints.
        :rtype: int
        """
        return self._min_in_gbs

    @min_in_gbs.setter
    def min_in_gbs(self, min_in_gbs):
        """
        Sets the min_in_gbs of this ImageMemoryConstraints.
        The minimum amount of memory, in gigabytes.


        :param min_in_gbs: The min_in_gbs of this ImageMemoryConstraints.
        :type: int
        """
        self._min_in_gbs = min_in_gbs

    @property
    def max_in_gbs(self):
        """
        Gets the max_in_gbs of this ImageMemoryConstraints.
        The maximum amount of memory, in gigabytes.


        :return: The max_in_gbs of this ImageMemoryConstraints.
        :rtype: int
        """
        return self._max_in_gbs

    @max_in_gbs.setter
    def max_in_gbs(self, max_in_gbs):
        """
        Sets the max_in_gbs of this ImageMemoryConstraints.
        The maximum amount of memory, in gigabytes.


        :param max_in_gbs: The max_in_gbs of this ImageMemoryConstraints.
        :type: int
        """
        self._max_in_gbs = max_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConnectionValidationSummary(object):
    """
    The information about connection validation
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConnectionValidationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param validation_message:
            The value to assign to the validation_message property of this ConnectionValidationSummary.
        :type validation_message: Message

        :param key:
            The value to assign to the key property of this ConnectionValidationSummary.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this ConnectionValidationSummary.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this ConnectionValidationSummary.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this ConnectionValidationSummary.
        :type parent_ref: ParentReference

        :param name:
            The value to assign to the name property of this ConnectionValidationSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this ConnectionValidationSummary.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this ConnectionValidationSummary.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this ConnectionValidationSummary.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this ConnectionValidationSummary.
        :type identifier: str

        :param metadata:
            The value to assign to the metadata property of this ConnectionValidationSummary.
        :type metadata: ObjectMetadata

        """
        self.swagger_types = {
            'validation_message': 'Message',
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'metadata': 'ObjectMetadata'
        }

        self.attribute_map = {
            'validation_message': 'validationMessage',
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'metadata': 'metadata'
        }

        self._validation_message = None
        self._key = None
        self._model_type = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._metadata = None

    @property
    def validation_message(self):
        """
        Gets the validation_message of this ConnectionValidationSummary.

        :return: The validation_message of this ConnectionValidationSummary.
        :rtype: Message
        """
        return self._validation_message

    @validation_message.setter
    def validation_message(self, validation_message):
        """
        Sets the validation_message of this ConnectionValidationSummary.

        :param validation_message: The validation_message of this ConnectionValidationSummary.
        :type: Message
        """
        self._validation_message = validation_message

    @property
    def key(self):
        """
        Gets the key of this ConnectionValidationSummary.
        Objects will use a 36 character key as unique ID. It is system generated and cannot be edited by user


        :return: The key of this ConnectionValidationSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ConnectionValidationSummary.
        Objects will use a 36 character key as unique ID. It is system generated and cannot be edited by user


        :param key: The key of this ConnectionValidationSummary.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        Gets the model_type of this ConnectionValidationSummary.
        The type of the object.


        :return: The model_type of this ConnectionValidationSummary.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this ConnectionValidationSummary.
        The type of the object.


        :param model_type: The model_type of this ConnectionValidationSummary.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this ConnectionValidationSummary.
        The model version of an object.


        :return: The model_version of this ConnectionValidationSummary.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this ConnectionValidationSummary.
        The model version of an object.


        :param model_version: The model_version of this ConnectionValidationSummary.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this ConnectionValidationSummary.

        :return: The parent_ref of this ConnectionValidationSummary.
        :rtype: ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this ConnectionValidationSummary.

        :param parent_ref: The parent_ref of this ConnectionValidationSummary.
        :type: ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this ConnectionValidationSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :return: The name of this ConnectionValidationSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConnectionValidationSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :param name: The name of this ConnectionValidationSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ConnectionValidationSummary.
        Detailed description for the object.


        :return: The description of this ConnectionValidationSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ConnectionValidationSummary.
        Detailed description for the object.


        :param description: The description of this ConnectionValidationSummary.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this ConnectionValidationSummary.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this ConnectionValidationSummary.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this ConnectionValidationSummary.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this ConnectionValidationSummary.
        :type: int
        """
        self._object_version = object_version

    @property
    def object_status(self):
        """
        Gets the object_status of this ConnectionValidationSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this ConnectionValidationSummary.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this ConnectionValidationSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this ConnectionValidationSummary.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this ConnectionValidationSummary.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be edited by the user.


        :return: The identifier of this ConnectionValidationSummary.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this ConnectionValidationSummary.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be edited by the user.


        :param identifier: The identifier of this ConnectionValidationSummary.
        :type: str
        """
        self._identifier = identifier

    @property
    def metadata(self):
        """
        Gets the metadata of this ConnectionValidationSummary.

        :return: The metadata of this ConnectionValidationSummary.
        :rtype: ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this ConnectionValidationSummary.

        :param metadata: The metadata of this ConnectionValidationSummary.
        :type: ObjectMetadata
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConnectRemotePeeringConnectionsDetails(object):
    """
    Information about the other remote peering connection (RPC).
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConnectRemotePeeringConnectionsDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param peer_id:
            The value to assign to the peer_id property of this ConnectRemotePeeringConnectionsDetails.
        :type peer_id: str

        :param peer_region_name:
            The value to assign to the peer_region_name property of this ConnectRemotePeeringConnectionsDetails.
        :type peer_region_name: str

        """
        self.swagger_types = {
            'peer_id': 'str',
            'peer_region_name': 'str'
        }

        self.attribute_map = {
            'peer_id': 'peerId',
            'peer_region_name': 'peerRegionName'
        }

        self._peer_id = None
        self._peer_region_name = None

    @property
    def peer_id(self):
        """
        **[Required]** Gets the peer_id of this ConnectRemotePeeringConnectionsDetails.
        The OCID of the RPC you want to peer with.


        :return: The peer_id of this ConnectRemotePeeringConnectionsDetails.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this ConnectRemotePeeringConnectionsDetails.
        The OCID of the RPC you want to peer with.


        :param peer_id: The peer_id of this ConnectRemotePeeringConnectionsDetails.
        :type: str
        """
        self._peer_id = peer_id

    @property
    def peer_region_name(self):
        """
        **[Required]** Gets the peer_region_name of this ConnectRemotePeeringConnectionsDetails.
        The name of the region that contains the RPC you want to peer with.

        Example: `us-ashburn-1`


        :return: The peer_region_name of this ConnectRemotePeeringConnectionsDetails.
        :rtype: str
        """
        return self._peer_region_name

    @peer_region_name.setter
    def peer_region_name(self, peer_region_name):
        """
        Sets the peer_region_name of this ConnectRemotePeeringConnectionsDetails.
        The name of the region that contains the RPC you want to peer with.

        Example: `us-ashburn-1`


        :param peer_region_name: The peer_region_name of this ConnectRemotePeeringConnectionsDetails.
        :type: str
        """
        self._peer_region_name = peer_region_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Threshold(object):
    """
    Threshold model.
    """

    #: A constant which can be used with the operator property of a Threshold.
    #: This constant has a value of "GT"
    OPERATOR_GT = "GT"

    #: A constant which can be used with the operator property of a Threshold.
    #: This constant has a value of "GTE"
    OPERATOR_GTE = "GTE"

    #: A constant which can be used with the operator property of a Threshold.
    #: This constant has a value of "LT"
    OPERATOR_LT = "LT"

    #: A constant which can be used with the operator property of a Threshold.
    #: This constant has a value of "LTE"
    OPERATOR_LTE = "LTE"

    def __init__(self, **kwargs):
        """
        Initializes a new Threshold object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operator:
            The value to assign to the operator property of this Threshold.
            Allowed values for this property are: "GT", "GTE", "LT", "LTE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operator: str

        :param value:
            The value to assign to the value property of this Threshold.
        :type value: int

        """
        self.swagger_types = {
            'operator': 'str',
            'value': 'int'
        }

        self.attribute_map = {
            'operator': 'operator',
            'value': 'value'
        }

        self._operator = None
        self._value = None

    @property
    def operator(self):
        """
        **[Required]** Gets the operator of this Threshold.
        The comparison operator to use. Options are greater than (`GT`), greater than or equal to
        (`GTE`), less than (`LT`), and less than or equal to (`LTE`).

        Allowed values for this property are: "GT", "GTE", "LT", "LTE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operator of this Threshold.
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """
        Sets the operator of this Threshold.
        The comparison operator to use. Options are greater than (`GT`), greater than or equal to
        (`GTE`), less than (`LT`), and less than or equal to (`LTE`).


        :param operator: The operator of this Threshold.
        :type: str
        """
        allowed_values = ["GT", "GTE", "LT", "LTE"]
        if not value_allowed_none_or_none_sentinel(operator, allowed_values):
            operator = 'UNKNOWN_ENUM_VALUE'
        self._operator = operator

    @property
    def value(self):
        """
        **[Required]** Gets the value of this Threshold.

        :return: The value of this Threshold.
        :rtype: int
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this Threshold.

        :param value: The value of this Threshold.
        :type: int
        """
        self._value = value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Stack(object):
    """
    The stack object. Stacks represent definitions of groups of Oracle Cloud Infrastructure
    resources that you can act upon as a group. You take action on stacks by using jobs.
    """

    #: A constant which can be used with the lifecycle_state property of a Stack.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Stack.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Stack.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Stack.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Stack.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the stack_drift_status property of a Stack.
    #: This constant has a value of "NOT_CHECKED"
    STACK_DRIFT_STATUS_NOT_CHECKED = "NOT_CHECKED"

    #: A constant which can be used with the stack_drift_status property of a Stack.
    #: This constant has a value of "IN_SYNC"
    STACK_DRIFT_STATUS_IN_SYNC = "IN_SYNC"

    #: A constant which can be used with the stack_drift_status property of a Stack.
    #: This constant has a value of "DRIFTED"
    STACK_DRIFT_STATUS_DRIFTED = "DRIFTED"

    def __init__(self, **kwargs):
        """
        Initializes a new Stack object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Stack.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Stack.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this Stack.
        :type display_name: str

        :param description:
            The value to assign to the description property of this Stack.
        :type description: str

        :param time_created:
            The value to assign to the time_created property of this Stack.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Stack.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param config_source:
            The value to assign to the config_source property of this Stack.
        :type config_source: ConfigSource

        :param variables:
            The value to assign to the variables property of this Stack.
        :type variables: dict(str, str)

        :param terraform_version:
            The value to assign to the terraform_version property of this Stack.
        :type terraform_version: str

        :param stack_drift_status:
            The value to assign to the stack_drift_status property of this Stack.
            Allowed values for this property are: "NOT_CHECKED", "IN_SYNC", "DRIFTED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type stack_drift_status: str

        :param time_drift_last_checked:
            The value to assign to the time_drift_last_checked property of this Stack.
        :type time_drift_last_checked: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Stack.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Stack.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'config_source': 'ConfigSource',
            'variables': 'dict(str, str)',
            'terraform_version': 'str',
            'stack_drift_status': 'str',
            'time_drift_last_checked': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'config_source': 'configSource',
            'variables': 'variables',
            'terraform_version': 'terraformVersion',
            'stack_drift_status': 'stackDriftStatus',
            'time_drift_last_checked': 'timeDriftLastChecked',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._description = None
        self._time_created = None
        self._lifecycle_state = None
        self._config_source = None
        self._variables = None
        self._terraform_version = None
        self._stack_drift_status = None
        self._time_drift_last_checked = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        Gets the id of this Stack.
        Unique identifier (`OCID`__) for the stack.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this Stack.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Stack.
        Unique identifier (`OCID`__) for the stack.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this Stack.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this Stack.
        Unique identifier (`OCID`__) for the compartment where the stack is located.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Stack.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Stack.
        Unique identifier (`OCID`__) for the compartment where the stack is located.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Stack.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this Stack.
        Human-readable name of the stack.


        :return: The display_name of this Stack.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Stack.
        Human-readable name of the stack.


        :param display_name: The display_name of this Stack.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this Stack.
        Description of the stack.


        :return: The description of this Stack.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Stack.
        Description of the stack.


        :param description: The description of this Stack.
        :type: str
        """
        self._description = description

    @property
    def time_created(self):
        """
        Gets the time_created of this Stack.
        The date and time at which the stack was created.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :return: The time_created of this Stack.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Stack.
        The date and time at which the stack was created.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :param time_created: The time_created of this Stack.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Stack.
        The current lifecycle state of the stack.
        For more information about stack lifecycle states in Resource Manager, see
        `Key Concepts`__.

        __ https://docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/resourcemanager.htm#StackStates

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Stack.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Stack.
        The current lifecycle state of the stack.
        For more information about stack lifecycle states in Resource Manager, see
        `Key Concepts`__.

        __ https://docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/resourcemanager.htm#StackStates


        :param lifecycle_state: The lifecycle_state of this Stack.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def config_source(self):
        """
        Gets the config_source of this Stack.

        :return: The config_source of this Stack.
        :rtype: ConfigSource
        """
        return self._config_source

    @config_source.setter
    def config_source(self, config_source):
        """
        Sets the config_source of this Stack.

        :param config_source: The config_source of this Stack.
        :type: ConfigSource
        """
        self._config_source = config_source

    @property
    def variables(self):
        """
        Gets the variables of this Stack.
        Terraform variables associated with this resource.
        Maximum number of variables supported is 250.
        The maximum size of each variable, including both name and value, is 4096 bytes.
        Example: `{\"CompartmentId\": \"compartment-id-value\"}`


        :return: The variables of this Stack.
        :rtype: dict(str, str)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """
        Sets the variables of this Stack.
        Terraform variables associated with this resource.
        Maximum number of variables supported is 250.
        The maximum size of each variable, including both name and value, is 4096 bytes.
        Example: `{\"CompartmentId\": \"compartment-id-value\"}`


        :param variables: The variables of this Stack.
        :type: dict(str, str)
        """
        self._variables = variables

    @property
    def terraform_version(self):
        """
        Gets the terraform_version of this Stack.
        The version of Terraform specified for the stack. Example: `0.12.x`


        :return: The terraform_version of this Stack.
        :rtype: str
        """
        return self._terraform_version

    @terraform_version.setter
    def terraform_version(self, terraform_version):
        """
        Sets the terraform_version of this Stack.
        The version of Terraform specified for the stack. Example: `0.12.x`


        :param terraform_version: The terraform_version of this Stack.
        :type: str
        """
        self._terraform_version = terraform_version

    @property
    def stack_drift_status(self):
        """
        Gets the stack_drift_status of this Stack.
        Drift status of the stack.
        Drift refers to differences between the actual (current) state of the stack and the expected (defined) state of the stack.

        Allowed values for this property are: "NOT_CHECKED", "IN_SYNC", "DRIFTED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The stack_drift_status of this Stack.
        :rtype: str
        """
        return self._stack_drift_status

    @stack_drift_status.setter
    def stack_drift_status(self, stack_drift_status):
        """
        Sets the stack_drift_status of this Stack.
        Drift status of the stack.
        Drift refers to differences between the actual (current) state of the stack and the expected (defined) state of the stack.


        :param stack_drift_status: The stack_drift_status of this Stack.
        :type: str
        """
        allowed_values = ["NOT_CHECKED", "IN_SYNC", "DRIFTED"]
        if not value_allowed_none_or_none_sentinel(stack_drift_status, allowed_values):
            stack_drift_status = 'UNKNOWN_ENUM_VALUE'
        self._stack_drift_status = stack_drift_status

    @property
    def time_drift_last_checked(self):
        """
        Gets the time_drift_last_checked of this Stack.
        The date and time when the drift detection was last executed.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :return: The time_drift_last_checked of this Stack.
        :rtype: datetime
        """
        return self._time_drift_last_checked

    @time_drift_last_checked.setter
    def time_drift_last_checked(self, time_drift_last_checked):
        """
        Sets the time_drift_last_checked of this Stack.
        The date and time when the drift detection was last executed.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :param time_drift_last_checked: The time_drift_last_checked of this Stack.
        :type: datetime
        """
        self._time_drift_last_checked = time_drift_last_checked

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Stack.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Stack.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Stack.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Stack.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Stack.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Stack.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Stack.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Stack.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_data_guard_association_details import CreateDataGuardAssociationDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDataGuardAssociationWithNewDbSystemDetails(CreateDataGuardAssociationDetails):
    """
    The configuration details for creating a Data Guard association for a virtual machine DB system database. For this type of DB system database, the `creationType` should be `NewDbSystem`. A new DB system will be launched to create the standby database.

    To create a Data Guard association for a database in a bare metal or Exadata DB system, use the :func:`create_data_guard_association_to_existing_db_system_details` subtype instead.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDataGuardAssociationWithNewDbSystemDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database.models.CreateDataGuardAssociationWithNewDbSystemDetails.creation_type` attribute
        of this class is ``NewDbSystem`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_admin_password:
            The value to assign to the database_admin_password property of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type database_admin_password: str

        :param protection_mode:
            The value to assign to the protection_mode property of this CreateDataGuardAssociationWithNewDbSystemDetails.
            Allowed values for this property are: "MAXIMUM_AVAILABILITY", "MAXIMUM_PERFORMANCE", "MAXIMUM_PROTECTION"
        :type protection_mode: str

        :param transport_type:
            The value to assign to the transport_type property of this CreateDataGuardAssociationWithNewDbSystemDetails.
            Allowed values for this property are: "SYNC", "ASYNC", "FASTSYNC"
        :type transport_type: str

        :param creation_type:
            The value to assign to the creation_type property of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type creation_type: str

        :param display_name:
            The value to assign to the display_name property of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type display_name: str

        :param availability_domain:
            The value to assign to the availability_domain property of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type availability_domain: str

        :param shape:
            The value to assign to the shape property of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type shape: str

        :param subnet_id:
            The value to assign to the subnet_id property of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type subnet_id: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type nsg_ids: list[str]

        :param backup_network_nsg_ids:
            The value to assign to the backup_network_nsg_ids property of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type backup_network_nsg_ids: list[str]

        :param hostname:
            The value to assign to the hostname property of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type hostname: str

        """
        self.swagger_types = {
            'database_admin_password': 'str',
            'protection_mode': 'str',
            'transport_type': 'str',
            'creation_type': 'str',
            'display_name': 'str',
            'availability_domain': 'str',
            'shape': 'str',
            'subnet_id': 'str',
            'nsg_ids': 'list[str]',
            'backup_network_nsg_ids': 'list[str]',
            'hostname': 'str'
        }

        self.attribute_map = {
            'database_admin_password': 'databaseAdminPassword',
            'protection_mode': 'protectionMode',
            'transport_type': 'transportType',
            'creation_type': 'creationType',
            'display_name': 'displayName',
            'availability_domain': 'availabilityDomain',
            'shape': 'shape',
            'subnet_id': 'subnetId',
            'nsg_ids': 'nsgIds',
            'backup_network_nsg_ids': 'backupNetworkNsgIds',
            'hostname': 'hostname'
        }

        self._database_admin_password = None
        self._protection_mode = None
        self._transport_type = None
        self._creation_type = None
        self._display_name = None
        self._availability_domain = None
        self._shape = None
        self._subnet_id = None
        self._nsg_ids = None
        self._backup_network_nsg_ids = None
        self._hostname = None
        self._creation_type = 'NewDbSystem'

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateDataGuardAssociationWithNewDbSystemDetails.
        The user-friendly name of the DB system that will contain the the standby database. The display name does not have to be unique.


        :return: The display_name of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateDataGuardAssociationWithNewDbSystemDetails.
        The user-friendly name of the DB system that will contain the the standby database. The display name does not have to be unique.


        :param display_name: The display_name of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this CreateDataGuardAssociationWithNewDbSystemDetails.
        The name of the availability domain that the standby database DB system will be located in. For example- \"Uocm:PHX-AD-1\".


        :return: The availability_domain of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this CreateDataGuardAssociationWithNewDbSystemDetails.
        The name of the availability domain that the standby database DB system will be located in. For example- \"Uocm:PHX-AD-1\".


        :param availability_domain: The availability_domain of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def shape(self):
        """
        Gets the shape of this CreateDataGuardAssociationWithNewDbSystemDetails.
        The virtual machine DB system shape to launch for the standby database in the Data Guard association. The shape determines the number of CPU cores and the amount of memory available for the DB system.
        Only virtual machine shapes are valid options. If you do not supply this parameter, the default shape is the shape of the primary DB system.

        To get a list of all shapes, use the :func:`list_db_system_shapes` operation.


        :return: The shape of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this CreateDataGuardAssociationWithNewDbSystemDetails.
        The virtual machine DB system shape to launch for the standby database in the Data Guard association. The shape determines the number of CPU cores and the amount of memory available for the DB system.
        Only virtual machine shapes are valid options. If you do not supply this parameter, the default shape is the shape of the primary DB system.

        To get a list of all shapes, use the :func:`list_db_system_shapes` operation.


        :param shape: The shape of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type: str
        """
        self._shape = shape

    @property
    def subnet_id(self):
        """
        Gets the subnet_id of this CreateDataGuardAssociationWithNewDbSystemDetails.
        The OCID of the subnet the DB system is associated with.
        **Subnet Restrictions:**
        - For 1- and 2-node RAC DB systems, do not use a subnet that overlaps with 192.168.16.16/28

        These subnets are used by the Oracle Clusterware private interconnect on the database instance.
        Specifying an overlapping subnet will cause the private interconnect to malfunction.
        This restriction applies to both the client subnet and backup subnet.


        :return: The subnet_id of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this CreateDataGuardAssociationWithNewDbSystemDetails.
        The OCID of the subnet the DB system is associated with.
        **Subnet Restrictions:**
        - For 1- and 2-node RAC DB systems, do not use a subnet that overlaps with 192.168.16.16/28

        These subnets are used by the Oracle Clusterware private interconnect on the database instance.
        Specifying an overlapping subnet will cause the private interconnect to malfunction.
        This restriction applies to both the client subnet and backup subnet.


        :param subnet_id: The subnet_id of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this CreateDataGuardAssociationWithNewDbSystemDetails.
        A list of the `OCIDs`__ of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :return: The nsg_ids of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this CreateDataGuardAssociationWithNewDbSystemDetails.
        A list of the `OCIDs`__ of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :param nsg_ids: The nsg_ids of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def backup_network_nsg_ids(self):
        """
        Gets the backup_network_nsg_ids of this CreateDataGuardAssociationWithNewDbSystemDetails.
        A list of the `OCIDs`__ of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__. Applicable only to Exadata DB systems.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :return: The backup_network_nsg_ids of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :rtype: list[str]
        """
        return self._backup_network_nsg_ids

    @backup_network_nsg_ids.setter
    def backup_network_nsg_ids(self, backup_network_nsg_ids):
        """
        Sets the backup_network_nsg_ids of this CreateDataGuardAssociationWithNewDbSystemDetails.
        A list of the `OCIDs`__ of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__. Applicable only to Exadata DB systems.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :param backup_network_nsg_ids: The backup_network_nsg_ids of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type: list[str]
        """
        self._backup_network_nsg_ids = backup_network_nsg_ids

    @property
    def hostname(self):
        """
        Gets the hostname of this CreateDataGuardAssociationWithNewDbSystemDetails.
        The hostname for the DB node.


        :return: The hostname of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """
        Sets the hostname of this CreateDataGuardAssociationWithNewDbSystemDetails.
        The hostname for the DB node.


        :param hostname: The hostname of this CreateDataGuardAssociationWithNewDbSystemDetails.
        :type: str
        """
        self._hostname = hostname

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# Note: This file is named py_ecdsa.py because import behavior in Python 2
# would cause ecdsa.py to squash the ecdsa library that it depends upon.

import hashlib

import ecdsa

from oci._vendor.jwt.algorithms import Algorithm
from oci._vendor.jwt.compat import string_types, text_type


class ECAlgorithm(Algorithm):
    """
    Performs signing and verification operations using
    ECDSA and the specified hash function

    This class requires the ecdsa package to be installed.

    This is based off of the implementation in PyJWT 0.3.2
    """
    SHA256 = hashlib.sha256
    SHA384 = hashlib.sha384
    SHA512 = hashlib.sha512

    def __init__(self, hash_alg):
        self.hash_alg = hash_alg

    def prepare_key(self, key):

        if isinstance(key, ecdsa.SigningKey) or \
           isinstance(key, ecdsa.VerifyingKey):
            return key

        if isinstance(key, string_types):
            if isinstance(key, text_type):
                key = key.encode('utf-8')

            # Attempt to load key. We don't know if it's
            # a Signing Key or a Verifying Key, so we try
            # the Verifying Key first.
            try:
                key = ecdsa.VerifyingKey.from_pem(key)
            except ecdsa.der.UnexpectedDER:
                key = ecdsa.SigningKey.from_pem(key)

        else:
            raise TypeError('Expecting a PEM-formatted key.')

        return key

    def sign(self, msg, key):
        return key.sign(msg, hashfunc=self.hash_alg,
                        sigencode=ecdsa.util.sigencode_string)

    def verify(self, msg, key, sig):
        try:
            return key.verify(sig, msg, hashfunc=self.hash_alg,
                              sigdecode=ecdsa.util.sigdecode_string)
        except AssertionError:
            return False



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PostMetricDataResponseDetails(object):
    """
    The response object returned from a PostMetricData operation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PostMetricDataResponseDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param failed_metrics_count:
            The value to assign to the failed_metrics_count property of this PostMetricDataResponseDetails.
        :type failed_metrics_count: int

        :param failed_metrics:
            The value to assign to the failed_metrics property of this PostMetricDataResponseDetails.
        :type failed_metrics: list[FailedMetricRecord]

        """
        self.swagger_types = {
            'failed_metrics_count': 'int',
            'failed_metrics': 'list[FailedMetricRecord]'
        }

        self.attribute_map = {
            'failed_metrics_count': 'failedMetricsCount',
            'failed_metrics': 'failedMetrics'
        }

        self._failed_metrics_count = None
        self._failed_metrics = None

    @property
    def failed_metrics_count(self):
        """
        **[Required]** Gets the failed_metrics_count of this PostMetricDataResponseDetails.
        The number of metric objects that failed input validation.


        :return: The failed_metrics_count of this PostMetricDataResponseDetails.
        :rtype: int
        """
        return self._failed_metrics_count

    @failed_metrics_count.setter
    def failed_metrics_count(self, failed_metrics_count):
        """
        Sets the failed_metrics_count of this PostMetricDataResponseDetails.
        The number of metric objects that failed input validation.


        :param failed_metrics_count: The failed_metrics_count of this PostMetricDataResponseDetails.
        :type: int
        """
        self._failed_metrics_count = failed_metrics_count

    @property
    def failed_metrics(self):
        """
        Gets the failed_metrics of this PostMetricDataResponseDetails.
        A list of records identifying metric objects that failed input validation
        and the reasons for the failures.


        :return: The failed_metrics of this PostMetricDataResponseDetails.
        :rtype: list[FailedMetricRecord]
        """
        return self._failed_metrics

    @failed_metrics.setter
    def failed_metrics(self, failed_metrics):
        """
        Sets the failed_metrics of this PostMetricDataResponseDetails.
        A list of records identifying metric objects that failed input validation
        and the reasons for the failures.


        :param failed_metrics: The failed_metrics of this PostMetricDataResponseDetails.
        :type: list[FailedMetricRecord]
        """
        self._failed_metrics = failed_metrics

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .authentication_policy import AuthenticationPolicy
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CustomAuthenticationPolicy(AuthenticationPolicy):
    """
    Use a function to validate a custom header or query parameter sent with the request authentication.
    A valid policy must specify either tokenHeader or tokenQueryParam.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CustomAuthenticationPolicy object with values from keyword arguments. The default value of the :py:attr:`~oci.apigateway.models.CustomAuthenticationPolicy.type` attribute
        of this class is ``CUSTOM_AUTHENTICATION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_anonymous_access_allowed:
            The value to assign to the is_anonymous_access_allowed property of this CustomAuthenticationPolicy.
        :type is_anonymous_access_allowed: bool

        :param type:
            The value to assign to the type property of this CustomAuthenticationPolicy.
            Allowed values for this property are: "CUSTOM_AUTHENTICATION", "JWT_AUTHENTICATION"
        :type type: str

        :param function_id:
            The value to assign to the function_id property of this CustomAuthenticationPolicy.
        :type function_id: str

        :param token_header:
            The value to assign to the token_header property of this CustomAuthenticationPolicy.
        :type token_header: str

        :param token_query_param:
            The value to assign to the token_query_param property of this CustomAuthenticationPolicy.
        :type token_query_param: str

        """
        self.swagger_types = {
            'is_anonymous_access_allowed': 'bool',
            'type': 'str',
            'function_id': 'str',
            'token_header': 'str',
            'token_query_param': 'str'
        }

        self.attribute_map = {
            'is_anonymous_access_allowed': 'isAnonymousAccessAllowed',
            'type': 'type',
            'function_id': 'functionId',
            'token_header': 'tokenHeader',
            'token_query_param': 'tokenQueryParam'
        }

        self._is_anonymous_access_allowed = None
        self._type = None
        self._function_id = None
        self._token_header = None
        self._token_query_param = None
        self._type = 'CUSTOM_AUTHENTICATION'

    @property
    def function_id(self):
        """
        **[Required]** Gets the function_id of this CustomAuthenticationPolicy.
        The `OCID`__ of the Oracle Functions function resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The function_id of this CustomAuthenticationPolicy.
        :rtype: str
        """
        return self._function_id

    @function_id.setter
    def function_id(self, function_id):
        """
        Sets the function_id of this CustomAuthenticationPolicy.
        The `OCID`__ of the Oracle Functions function resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param function_id: The function_id of this CustomAuthenticationPolicy.
        :type: str
        """
        self._function_id = function_id

    @property
    def token_header(self):
        """
        Gets the token_header of this CustomAuthenticationPolicy.
        The name of the header containing the authentication token.


        :return: The token_header of this CustomAuthenticationPolicy.
        :rtype: str
        """
        return self._token_header

    @token_header.setter
    def token_header(self, token_header):
        """
        Sets the token_header of this CustomAuthenticationPolicy.
        The name of the header containing the authentication token.


        :param token_header: The token_header of this CustomAuthenticationPolicy.
        :type: str
        """
        self._token_header = token_header

    @property
    def token_query_param(self):
        """
        Gets the token_query_param of this CustomAuthenticationPolicy.
        The name of the query parameter containing the authentication token.


        :return: The token_query_param of this CustomAuthenticationPolicy.
        :rtype: str
        """
        return self._token_query_param

    @token_query_param.setter
    def token_query_param(self, token_query_param):
        """
        Sets the token_query_param of this CustomAuthenticationPolicy.
        The name of the query parameter containing the authentication token.


        :param token_query_param: The token_query_param of this CustomAuthenticationPolicy.
        :type: str
        """
        self._token_query_param = token_query_param

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NotebookSessionConfigurationDetails(object):
    """
    Details for the notebook session configuration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NotebookSessionConfigurationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param shape:
            The value to assign to the shape property of this NotebookSessionConfigurationDetails.
        :type shape: str

        :param block_storage_size_in_gbs:
            The value to assign to the block_storage_size_in_gbs property of this NotebookSessionConfigurationDetails.
        :type block_storage_size_in_gbs: int

        :param subnet_id:
            The value to assign to the subnet_id property of this NotebookSessionConfigurationDetails.
        :type subnet_id: str

        """
        self.swagger_types = {
            'shape': 'str',
            'block_storage_size_in_gbs': 'int',
            'subnet_id': 'str'
        }

        self.attribute_map = {
            'shape': 'shape',
            'block_storage_size_in_gbs': 'blockStorageSizeInGBs',
            'subnet_id': 'subnetId'
        }

        self._shape = None
        self._block_storage_size_in_gbs = None
        self._subnet_id = None

    @property
    def shape(self):
        """
        **[Required]** Gets the shape of this NotebookSessionConfigurationDetails.
        The shape used to launch the notebook session compute instance.  The list of available shapes in a given compartment can be retrieved from the `ListNotebookSessionShapes` endpoint.


        :return: The shape of this NotebookSessionConfigurationDetails.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this NotebookSessionConfigurationDetails.
        The shape used to launch the notebook session compute instance.  The list of available shapes in a given compartment can be retrieved from the `ListNotebookSessionShapes` endpoint.


        :param shape: The shape of this NotebookSessionConfigurationDetails.
        :type: str
        """
        self._shape = shape

    @property
    def block_storage_size_in_gbs(self):
        """
        Gets the block_storage_size_in_gbs of this NotebookSessionConfigurationDetails.
        A notebook session instance is provided with a block storage volume. This specifies the size of the volume in GBs.


        :return: The block_storage_size_in_gbs of this NotebookSessionConfigurationDetails.
        :rtype: int
        """
        return self._block_storage_size_in_gbs

    @block_storage_size_in_gbs.setter
    def block_storage_size_in_gbs(self, block_storage_size_in_gbs):
        """
        Sets the block_storage_size_in_gbs of this NotebookSessionConfigurationDetails.
        A notebook session instance is provided with a block storage volume. This specifies the size of the volume in GBs.


        :param block_storage_size_in_gbs: The block_storage_size_in_gbs of this NotebookSessionConfigurationDetails.
        :type: int
        """
        self._block_storage_size_in_gbs = block_storage_size_in_gbs

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this NotebookSessionConfigurationDetails.
        A notebook session instance is provided with a VNIC for network access.  This specifies the `OCID`__ of the subnet to create a VNIC in.  The subnet should be in a VCN with a NAT gateway for egress to the internet.

        __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/identifiers.htm


        :return: The subnet_id of this NotebookSessionConfigurationDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this NotebookSessionConfigurationDetails.
        A notebook session instance is provided with a VNIC for network access.  This specifies the `OCID`__ of the subnet to create a VNIC in.  The subnet should be in a VCN with a NAT gateway for egress to the internet.

        __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this NotebookSessionConfigurationDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BlockchainPlatform(object):
    """
    Blockchain Platform Instance Description.
    """

    #: A constant which can be used with the platform_role property of a BlockchainPlatform.
    #: This constant has a value of "FOUNDER"
    PLATFORM_ROLE_FOUNDER = "FOUNDER"

    #: A constant which can be used with the platform_role property of a BlockchainPlatform.
    #: This constant has a value of "PARTICIPANT"
    PLATFORM_ROLE_PARTICIPANT = "PARTICIPANT"

    #: A constant which can be used with the compute_shape property of a BlockchainPlatform.
    #: This constant has a value of "STANDARD"
    COMPUTE_SHAPE_STANDARD = "STANDARD"

    #: A constant which can be used with the compute_shape property of a BlockchainPlatform.
    #: This constant has a value of "ENTERPRISE_SMALL"
    COMPUTE_SHAPE_ENTERPRISE_SMALL = "ENTERPRISE_SMALL"

    #: A constant which can be used with the compute_shape property of a BlockchainPlatform.
    #: This constant has a value of "ENTERPRISE_MEDIUM"
    COMPUTE_SHAPE_ENTERPRISE_MEDIUM = "ENTERPRISE_MEDIUM"

    #: A constant which can be used with the compute_shape property of a BlockchainPlatform.
    #: This constant has a value of "ENTERPRISE_LARGE"
    COMPUTE_SHAPE_ENTERPRISE_LARGE = "ENTERPRISE_LARGE"

    #: A constant which can be used with the compute_shape property of a BlockchainPlatform.
    #: This constant has a value of "ENTERPRISE_EXTRA_LARGE"
    COMPUTE_SHAPE_ENTERPRISE_EXTRA_LARGE = "ENTERPRISE_EXTRA_LARGE"

    #: A constant which can be used with the compute_shape property of a BlockchainPlatform.
    #: This constant has a value of "ENTERPRISE_CUSTOM"
    COMPUTE_SHAPE_ENTERPRISE_CUSTOM = "ENTERPRISE_CUSTOM"

    #: A constant which can be used with the lifecycle_state property of a BlockchainPlatform.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a BlockchainPlatform.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a BlockchainPlatform.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a BlockchainPlatform.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a BlockchainPlatform.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a BlockchainPlatform.
    #: This constant has a value of "SCALING"
    LIFECYCLE_STATE_SCALING = "SCALING"

    #: A constant which can be used with the lifecycle_state property of a BlockchainPlatform.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a BlockchainPlatform.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new BlockchainPlatform object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this BlockchainPlatform.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this BlockchainPlatform.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this BlockchainPlatform.
        :type compartment_id: str

        :param description:
            The value to assign to the description property of this BlockchainPlatform.
        :type description: str

        :param is_byol:
            The value to assign to the is_byol property of this BlockchainPlatform.
        :type is_byol: bool

        :param time_created:
            The value to assign to the time_created property of this BlockchainPlatform.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this BlockchainPlatform.
        :type time_updated: datetime

        :param service_version:
            The value to assign to the service_version property of this BlockchainPlatform.
        :type service_version: str

        :param platform_role:
            The value to assign to the platform_role property of this BlockchainPlatform.
            Allowed values for this property are: "FOUNDER", "PARTICIPANT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type platform_role: str

        :param compute_shape:
            The value to assign to the compute_shape property of this BlockchainPlatform.
            Allowed values for this property are: "STANDARD", "ENTERPRISE_SMALL", "ENTERPRISE_MEDIUM", "ENTERPRISE_LARGE", "ENTERPRISE_EXTRA_LARGE", "ENTERPRISE_CUSTOM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type compute_shape: str

        :param service_endpoint:
            The value to assign to the service_endpoint property of this BlockchainPlatform.
        :type service_endpoint: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this BlockchainPlatform.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "SCALING", "INACTIVE", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this BlockchainPlatform.
        :type lifecycle_details: str

        :param storage_size_in_tbs:
            The value to assign to the storage_size_in_tbs property of this BlockchainPlatform.
        :type storage_size_in_tbs: float

        :param storage_used_in_t_bs:
            The value to assign to the storage_used_in_t_bs property of this BlockchainPlatform.
        :type storage_used_in_t_bs: float

        :param is_multi_ad:
            The value to assign to the is_multi_ad property of this BlockchainPlatform.
        :type is_multi_ad: bool

        :param total_ocpu_capacity:
            The value to assign to the total_ocpu_capacity property of this BlockchainPlatform.
        :type total_ocpu_capacity: int

        :param component_details:
            The value to assign to the component_details property of this BlockchainPlatform.
        :type component_details: BlockchainPlatformComponentDetails

        :param replicas:
            The value to assign to the replicas property of this BlockchainPlatform.
        :type replicas: ReplicaDetails

        :param host_ocpu_utilization_info:
            The value to assign to the host_ocpu_utilization_info property of this BlockchainPlatform.
        :type host_ocpu_utilization_info: list[OcpuUtilizationInfo]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this BlockchainPlatform.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this BlockchainPlatform.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'description': 'str',
            'is_byol': 'bool',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'service_version': 'str',
            'platform_role': 'str',
            'compute_shape': 'str',
            'service_endpoint': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'storage_size_in_tbs': 'float',
            'storage_used_in_t_bs': 'float',
            'is_multi_ad': 'bool',
            'total_ocpu_capacity': 'int',
            'component_details': 'BlockchainPlatformComponentDetails',
            'replicas': 'ReplicaDetails',
            'host_ocpu_utilization_info': 'list[OcpuUtilizationInfo]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'description': 'description',
            'is_byol': 'isByol',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'service_version': 'serviceVersion',
            'platform_role': 'platformRole',
            'compute_shape': 'computeShape',
            'service_endpoint': 'serviceEndpoint',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'storage_size_in_tbs': 'storageSizeInTBs',
            'storage_used_in_t_bs': 'storageUsedInTBs',
            'is_multi_ad': 'isMultiAD',
            'total_ocpu_capacity': 'totalOcpuCapacity',
            'component_details': 'componentDetails',
            'replicas': 'replicas',
            'host_ocpu_utilization_info': 'hostOcpuUtilizationInfo',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._description = None
        self._is_byol = None
        self._time_created = None
        self._time_updated = None
        self._service_version = None
        self._platform_role = None
        self._compute_shape = None
        self._service_endpoint = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._storage_size_in_tbs = None
        self._storage_used_in_t_bs = None
        self._is_multi_ad = None
        self._total_ocpu_capacity = None
        self._component_details = None
        self._replicas = None
        self._host_ocpu_utilization_info = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this BlockchainPlatform.
        unique identifier that is immutable on creation


        :return: The id of this BlockchainPlatform.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BlockchainPlatform.
        unique identifier that is immutable on creation


        :param id: The id of this BlockchainPlatform.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this BlockchainPlatform.
        Platform Instance Display name, can be renamed


        :return: The display_name of this BlockchainPlatform.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this BlockchainPlatform.
        Platform Instance Display name, can be renamed


        :param display_name: The display_name of this BlockchainPlatform.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this BlockchainPlatform.
        Compartment Identifier


        :return: The compartment_id of this BlockchainPlatform.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this BlockchainPlatform.
        Compartment Identifier


        :param compartment_id: The compartment_id of this BlockchainPlatform.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def description(self):
        """
        Gets the description of this BlockchainPlatform.
        Platform Instance Description


        :return: The description of this BlockchainPlatform.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this BlockchainPlatform.
        Platform Instance Description


        :param description: The description of this BlockchainPlatform.
        :type: str
        """
        self._description = description

    @property
    def is_byol(self):
        """
        Gets the is_byol of this BlockchainPlatform.
        Bring your own license


        :return: The is_byol of this BlockchainPlatform.
        :rtype: bool
        """
        return self._is_byol

    @is_byol.setter
    def is_byol(self, is_byol):
        """
        Sets the is_byol of this BlockchainPlatform.
        Bring your own license


        :param is_byol: The is_byol of this BlockchainPlatform.
        :type: bool
        """
        self._is_byol = is_byol

    @property
    def time_created(self):
        """
        Gets the time_created of this BlockchainPlatform.
        The time the the Platform Instance was created. An RFC3339 formatted datetime string


        :return: The time_created of this BlockchainPlatform.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this BlockchainPlatform.
        The time the the Platform Instance was created. An RFC3339 formatted datetime string


        :param time_created: The time_created of this BlockchainPlatform.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this BlockchainPlatform.
        The time the Platform Instance was updated. An RFC3339 formatted datetime string


        :return: The time_updated of this BlockchainPlatform.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this BlockchainPlatform.
        The time the Platform Instance was updated. An RFC3339 formatted datetime string


        :param time_updated: The time_updated of this BlockchainPlatform.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def service_version(self):
        """
        Gets the service_version of this BlockchainPlatform.
        The version of the Platform Instance.


        :return: The service_version of this BlockchainPlatform.
        :rtype: str
        """
        return self._service_version

    @service_version.setter
    def service_version(self, service_version):
        """
        Sets the service_version of this BlockchainPlatform.
        The version of the Platform Instance.


        :param service_version: The service_version of this BlockchainPlatform.
        :type: str
        """
        self._service_version = service_version

    @property
    def platform_role(self):
        """
        **[Required]** Gets the platform_role of this BlockchainPlatform.
        Role of platform - founder or participant

        Allowed values for this property are: "FOUNDER", "PARTICIPANT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The platform_role of this BlockchainPlatform.
        :rtype: str
        """
        return self._platform_role

    @platform_role.setter
    def platform_role(self, platform_role):
        """
        Sets the platform_role of this BlockchainPlatform.
        Role of platform - founder or participant


        :param platform_role: The platform_role of this BlockchainPlatform.
        :type: str
        """
        allowed_values = ["FOUNDER", "PARTICIPANT"]
        if not value_allowed_none_or_none_sentinel(platform_role, allowed_values):
            platform_role = 'UNKNOWN_ENUM_VALUE'
        self._platform_role = platform_role

    @property
    def compute_shape(self):
        """
        **[Required]** Gets the compute_shape of this BlockchainPlatform.
        Type of compute shape - one of Standard, (Enterprise) Small, Medium, Large or Extra Large

        Allowed values for this property are: "STANDARD", "ENTERPRISE_SMALL", "ENTERPRISE_MEDIUM", "ENTERPRISE_LARGE", "ENTERPRISE_EXTRA_LARGE", "ENTERPRISE_CUSTOM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The compute_shape of this BlockchainPlatform.
        :rtype: str
        """
        return self._compute_shape

    @compute_shape.setter
    def compute_shape(self, compute_shape):
        """
        Sets the compute_shape of this BlockchainPlatform.
        Type of compute shape - one of Standard, (Enterprise) Small, Medium, Large or Extra Large


        :param compute_shape: The compute_shape of this BlockchainPlatform.
        :type: str
        """
        allowed_values = ["STANDARD", "ENTERPRISE_SMALL", "ENTERPRISE_MEDIUM", "ENTERPRISE_LARGE", "ENTERPRISE_EXTRA_LARGE", "ENTERPRISE_CUSTOM"]
        if not value_allowed_none_or_none_sentinel(compute_shape, allowed_values):
            compute_shape = 'UNKNOWN_ENUM_VALUE'
        self._compute_shape = compute_shape

    @property
    def service_endpoint(self):
        """
        Gets the service_endpoint of this BlockchainPlatform.
        Service endpoint URL, valid post-provisioning


        :return: The service_endpoint of this BlockchainPlatform.
        :rtype: str
        """
        return self._service_endpoint

    @service_endpoint.setter
    def service_endpoint(self, service_endpoint):
        """
        Sets the service_endpoint of this BlockchainPlatform.
        Service endpoint URL, valid post-provisioning


        :param service_endpoint: The service_endpoint of this BlockchainPlatform.
        :type: str
        """
        self._service_endpoint = service_endpoint

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this BlockchainPlatform.
        The current state of the Platform Instance.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "SCALING", "INACTIVE", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this BlockchainPlatform.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this BlockchainPlatform.
        The current state of the Platform Instance.


        :param lifecycle_state: The lifecycle_state of this BlockchainPlatform.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "SCALING", "INACTIVE", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this BlockchainPlatform.
        An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecycle_details of this BlockchainPlatform.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this BlockchainPlatform.
        An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecycle_details: The lifecycle_details of this BlockchainPlatform.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def storage_size_in_tbs(self):
        """
        Gets the storage_size_in_tbs of this BlockchainPlatform.
        Storage size in TBs


        :return: The storage_size_in_tbs of this BlockchainPlatform.
        :rtype: float
        """
        return self._storage_size_in_tbs

    @storage_size_in_tbs.setter
    def storage_size_in_tbs(self, storage_size_in_tbs):
        """
        Sets the storage_size_in_tbs of this BlockchainPlatform.
        Storage size in TBs


        :param storage_size_in_tbs: The storage_size_in_tbs of this BlockchainPlatform.
        :type: float
        """
        self._storage_size_in_tbs = storage_size_in_tbs

    @property
    def storage_used_in_t_bs(self):
        """
        Gets the storage_used_in_t_bs of this BlockchainPlatform.
        Storage used in TBs


        :return: The storage_used_in_t_bs of this BlockchainPlatform.
        :rtype: float
        """
        return self._storage_used_in_t_bs

    @storage_used_in_t_bs.setter
    def storage_used_in_t_bs(self, storage_used_in_t_bs):
        """
        Sets the storage_used_in_t_bs of this BlockchainPlatform.
        Storage used in TBs


        :param storage_used_in_t_bs: The storage_used_in_t_bs of this BlockchainPlatform.
        :type: float
        """
        self._storage_used_in_t_bs = storage_used_in_t_bs

    @property
    def is_multi_ad(self):
        """
        Gets the is_multi_ad of this BlockchainPlatform.
        True for multi-AD blockchain plaforms, false for single-AD


        :return: The is_multi_ad of this BlockchainPlatform.
        :rtype: bool
        """
        return self._is_multi_ad

    @is_multi_ad.setter
    def is_multi_ad(self, is_multi_ad):
        """
        Sets the is_multi_ad of this BlockchainPlatform.
        True for multi-AD blockchain plaforms, false for single-AD


        :param is_multi_ad: The is_multi_ad of this BlockchainPlatform.
        :type: bool
        """
        self._is_multi_ad = is_multi_ad

    @property
    def total_ocpu_capacity(self):
        """
        Gets the total_ocpu_capacity of this BlockchainPlatform.
        Number of total OCPUs allocated to the platform cluster


        :return: The total_ocpu_capacity of this BlockchainPlatform.
        :rtype: int
        """
        return self._total_ocpu_capacity

    @total_ocpu_capacity.setter
    def total_ocpu_capacity(self, total_ocpu_capacity):
        """
        Sets the total_ocpu_capacity of this BlockchainPlatform.
        Number of total OCPUs allocated to the platform cluster


        :param total_ocpu_capacity: The total_ocpu_capacity of this BlockchainPlatform.
        :type: int
        """
        self._total_ocpu_capacity = total_ocpu_capacity

    @property
    def component_details(self):
        """
        Gets the component_details of this BlockchainPlatform.

        :return: The component_details of this BlockchainPlatform.
        :rtype: BlockchainPlatformComponentDetails
        """
        return self._component_details

    @component_details.setter
    def component_details(self, component_details):
        """
        Sets the component_details of this BlockchainPlatform.

        :param component_details: The component_details of this BlockchainPlatform.
        :type: BlockchainPlatformComponentDetails
        """
        self._component_details = component_details

    @property
    def replicas(self):
        """
        Gets the replicas of this BlockchainPlatform.

        :return: The replicas of this BlockchainPlatform.
        :rtype: ReplicaDetails
        """
        return self._replicas

    @replicas.setter
    def replicas(self, replicas):
        """
        Sets the replicas of this BlockchainPlatform.

        :param replicas: The replicas of this BlockchainPlatform.
        :type: ReplicaDetails
        """
        self._replicas = replicas

    @property
    def host_ocpu_utilization_info(self):
        """
        Gets the host_ocpu_utilization_info of this BlockchainPlatform.
        List of OcpuUtilization for all hosts


        :return: The host_ocpu_utilization_info of this BlockchainPlatform.
        :rtype: list[OcpuUtilizationInfo]
        """
        return self._host_ocpu_utilization_info

    @host_ocpu_utilization_info.setter
    def host_ocpu_utilization_info(self, host_ocpu_utilization_info):
        """
        Sets the host_ocpu_utilization_info of this BlockchainPlatform.
        List of OcpuUtilization for all hosts


        :param host_ocpu_utilization_info: The host_ocpu_utilization_info of this BlockchainPlatform.
        :type: list[OcpuUtilizationInfo]
        """
        self._host_ocpu_utilization_info = host_ocpu_utilization_info

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this BlockchainPlatform.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this BlockchainPlatform.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this BlockchainPlatform.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this BlockchainPlatform.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this BlockchainPlatform.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this BlockchainPlatform.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this BlockchainPlatform.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this BlockchainPlatform.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
